@@ -23,18 +23,16 @@
 #include "about.h"
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
-#include "version.h"
 
 #include <QFileDialog>
 #include <QScrollBar>
 #include <QTextStream>
-
+#include "unistd.h"
 #include <QDebug>
 
 MainWindow::MainWindow(const QStringList& args) :
     ui(new Ui::MainWindow)
 {
-    qDebug().noquote() << QCoreApplication::applicationName() << "version:" << VERSION;
     ui->setupUi(this);
 
     // setup options
@@ -165,8 +163,8 @@ void MainWindow::setup()
     ui->outputBox->setCursorWidth(0);
     height = this->heightMM();
 
-    QRegExp rx("\\w*");
-    QValidator *validator = new QRegExpValidator(rx, this);
+    QRegularExpression rx("\\w*");
+    QValidator *validator = new QRegularExpressionValidator(rx, this);
     ui->edit_label->setValidator(validator);
 
     //set save boot directory option to disable unless update mode is checked
@@ -253,6 +251,12 @@ QString MainWindow::buildOptionList()
 // cleanup environment when window is closed
 void MainWindow::cleanup()
 {
+    QFileInfo lum(LUM);
+    QFileInfo logfile("/tmp/" + lum.baseName() + ".log");
+    if ( logfile.exists() ) {
+        QString removecmd = "rm -f " + logfile.absoluteFilePath();
+        system(removecmd.toUtf8());
+    }
     cmd.halt();
 }
 
@@ -381,7 +385,7 @@ void MainWindow::on_buttonNext_clicked()
     } else if (ui->stackedWidget->currentWidget() == ui->outputPage) {
 
     } else {
-        return qApp->quit();
+        qApp->quit();
     }
 }
 
@@ -401,7 +405,7 @@ void MainWindow::on_buttonAbout_clicked()
 {
     this->hide();
     displayAboutMsgBox(tr("About %1").arg(this->windowTitle()), "<p align=\"center\"><b><h2>" + this->windowTitle() +"</h2></b></p><p align=\"center\">" +
-                       tr("Version: ") + VERSION + "</p><p align=\"center\"><h3>" +
+                       tr("Version: ") + qApp->applicationVersion() + "</p><p align=\"center\"><h3>" +
                        tr("Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.") +
                        "</h3></p><p align=\"center\"><a href=\"http://mxlinux.org\">http://mxlinux.org</a><br /></p><p align=\"center\">" +
                        tr("Copyright (c) MX Linux") + "<br /><br /></p>",
@@ -605,3 +609,35 @@ bool MainWindow::isantiX_mx_family(QString selected)
         return false;
     }
 }
+
+void MainWindow::on_pushButtonLumLogFile_clicked()
+{
+    QFileInfo lum(LUM);
+    QString url = "file:///tmp/" + lum.baseName() + ".log";
+    qDebug() << "lumlog" << url;
+    if (!QFileInfo::exists(url)) {
+        QMessageBox::information(this, qApp->applicationName(), tr("Could not find a log file at: ") + url);
+        return;
+    }
+    QFileInfo viewer("/usr/bin/mx-viewer");
+    QFileInfo viewer2("/usr/bin/antix-viewer");
+    QString rootrunoption = QString();
+    QString cmd;
+
+    // generate temporary log file
+    cmd = "tac /var/log/" + lum.baseName() + ".log | sed \"/^=\\{60\\}=*$/q\" > /tmp/" + lum.baseName() + ".log";
+    system(cmd.toUtf8());
+
+    if (getuid() == 0) {
+        rootrunoption = "runuser -l $(logname) -c ";
+    }
+
+    if (viewer.exists()) {
+        cmd = QString("mx-viewer %1 '%2' &").arg(url).arg(lum.baseName());
+    } else if (viewer2.exists()) {
+        cmd = QString("antix-viewer %1 '%2' &").arg(url).arg(lum.baseName());
+    } else {
+        cmd = QString(rootrunoption + "\"DISPLAY=$DISPLAY xdg-open %1\" &").arg(url);
+    }
+    system(cmd.toUtf8());
+}
